<?php

namespace Drupal\webform_revisions;

require_once __DIR__ . '/../webform_revisions.inc';

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Trait WebformRevisionsDataAccess.
 *
 * Provide functions used in the different classes to perform CRUD on the
 * content entity ID in the config entity and other functions that are needed
 * in multiple places.
 *
 * @package Drupal\config_entity_revisions
 */
trait WebformRevisionsDataAccessTrait {

  /**
   * Set in the configEntity an identifier for the matching content entity.
   *
   * @param ConfigEntityInterface $configEntity
   *   The config entity to be modified.
   * @param mixed $contentEntityID
   *   The ID used to match the content entity.
   */
  public function setContentEntityIDInConfigEntity(ConfigEntityInterface $entity, $contentEntityID) {
    $entity->setThirdPartySetting(MODULE_NAME, CONFIG_ENTITY_SETTING_NAME, $contentEntityID);
  }

  /**
   * Get from the configEntity the ID of the matching content entity.
   *
   * @param ConfigEntityInterface $entity
   *  The config entity to be modified.
   *
   * @return int|null
   *   The ID (if any) of the matching content entity.
   */
  public function getContentEntityIDInConfigEntity(ConfigEntityInterface $entity) {
    return $entity->getThirdPartySetting(MODULE_NAME, CONFIG_ENTITY_SETTING_NAME);
  }

  /**
   * Revisions entity for config entity.
   *
   * @param ConfigEntityInterface $configEntity
   *   The config entity for which the revisions entity should be retrieved.
   *
   * @return \Drupal\Core\Entity\ContentEntityInterface|null
   *   The matching entity.
   */
  public function getContentEntityFromConfigEntity(ConfigEntityInterface $config_entity) {
    $contentEntityID = $this->getContentEntityIDInConfigEntity($config_entity);

    if (!$contentEntityID) {
      return NULL;
    }

    return $this->contentEntityStorage()->loadRevision($config_entity->get('revision_id'));
  }

}
