<?php

namespace Drupal\config_entity_revisions;

use Drupal\Core\Session\AccountInterface;

/**
 * Node specific entity access control methods.
 *
 * @ingroup config_entity_revisions_access
 */
interface ConfigEntityRevisionsAccessControlHandlerInterface {

  /**
   * Gets the list of config_entity_revisions access grants.
   *
   * @param ConfigEntityRevisionsInterface $revisions
   *   The $revision to acquire grants for.
   *
   * @return array
   *   The access rules for the config entity revisions entity.
   */
  public function acquireGrants(ConfigEntityRevisionsInterface $revisions);

  /**
   * Writes a list of grants to the database, deleting any previously saved ones.
   *
   * Modules that use revision access can use this function when doing mass updates
   * due to widespread permission changes.
   *
   * @param ConfigEntityRevisionsInterface $revisions
   *   The revision whose grants are being written.
   * @param $delete
   *   (optional) If false, does not delete records. This is only for optimization
   *   purposes, and assumes the caller has already performed a mass delete of
   *   some form. Defaults to TRUE.
   */
  public function writeGrants(ConfigEntityRevisionsInterface $revisions, $delete = TRUE);

  /**
   * Creates the default config entity revision access grant entry on the grant storage.
   */
  public function writeDefaultGrant();

  /**
   * Deletes all config entity revision access entries.
   */
  public function deleteGrants();

  /**
   * Counts available config entity revision grants.
   *
   * @return int
   *   Returns the number of config entity revision grants.
   */
  public function countGrants();

  /**
   * Checks all grants for a given account.
   *
   * @param \Drupal\Core\Session\AccountInterface $account
   *   A user object representing the user for whom the operation is to be
   *   performed.
   *
   * @return int
   *   Status of the access check.
   */
  public function checkAllGrants(AccountInterface $account);

}
