<?php

namespace Drupal\config_entity_revisions;

use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\diff\DiffEntityComparison;
use Drupal\Core\Entity\EntityTypeManager;
use Drupal\Core\Config\Entity\ConfigEntityInterface;
use Symfony\Component\Serializer\Serializer;

/**
 * ConfigEntityRevisionsController interface.
 */
interface ConfigEntityRevisionsControllerInterface {

  /**
   * Constructs a ConfigEntityRevisionsController object.
   *
   * @param ContainerInterface $container
   *   The container interface object.
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date formatter service.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   * @param \Drupal\Core\Config\ImmutableConfig $config
   *   The configuration service.
   * @param \Drupal\diff\DiffEntityComparison $entity_comparison
   *   The diff entity comparison service.
   * @param \Drupal\Core\Entity\EntityTypeManager $entity_type_manager
   *   The entity type manager.
   * @param AccountProxyInterface $current_user
   *   The current user.
   * @param Serialiser
   *   The serialiser service.
   */
  public function __construct(ContainerInterface $container, DateFormatterInterface $date_formatter, RendererInterface $renderer, ImmutableConfig $config, DiffEntityComparison $entity_comparison, EntityTypeManager $entity_type_manager, AccountProxyInterface $current_user, Serializer $serialiser);

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container);

  /**
   * Create an initial revision record.
   *
   * @param ConfigEntityInterface $config_entity
   *   The configuration entity.
   *
   * @return ContentEntityInterface
   *   The content entity created.
   */
  public function createInitalRevision(ConfigEntityInterface $config_entity);

  /**
   * Create revision when a new config entity version is saved.
   *
   * @param ConfigEntityInterface $config_entity
   *   The configuration entity.
   */
  public function createUpdateRevision(ConfigEntityInterface $config_entity);

  /**
   * Delete revisions when a config entity is deleted.
   *
   * @param ConfigEntityInterface $config_entity
   *   The configuration entity being deleted.
   */
  public function deleteRevisions(ConfigEntityInterface $config_entity);

  /**
   * Renderer for a revision.
   *
   * @param int $revision_id
   *   The ID of the revision to display.
   *
   * @return array
   *   The resulting render array.
   */
  public function revisionShow(int $revision_id);

  /**
   * Default implementation providing a title for a rendered revision.
   *
   * @param ConfigEntityInterface $config_entity
   *   The configuration entity being displayed.
   *
   * @return string
   *   The resulting title.
   */
  public function revisionShowTitle(ConfigEntityInterface $config_entity);

  /**
   * Default implementation providing a title for editing a revision.
   *
   * @param ConfigEntityInterface $config_entity
   *   The configuration entity being displayed.
   *
   * @return string
   *   The resulting title.
   */
  public function revisionEditTitle(ConfigEntityInterface $config_entity, int $revision_id);
}
