<?php

namespace Drupal\config_entity_revisions;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityOwnerInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\Core\Entity\RevisionLogInterface;

/**
 * Provides an interface defining a config entity revisions entity.
 */
interface ConfigEntityRevisionsInterface extends ContentEntityInterface, EntityChangedInterface, RevisionLogInterface {

  /**
   * Returns the creation timestamp.
   *
   * @return int
   *   Creation timestamp of the revisions entity.
   */
  public function getCreatedTime();

  /**
   * Sets the revisions entity creation timestamp.
   *
   * @param int $timestamp
   *   The revisions entity creation timestamp.
   *
   * @return \Drupal\config_entity_revisions\ConfigEntityRevisionsInterface
   *   The called revisions entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the revisions entity publisher user entity.
   *
   * @return \Drupal\user\UserInterface
   *   The author user entity.
   */
  public function getPublisher();

  /**
   * Returns the revisions entity publisher user ID.
   *
   * @return int
   *   The author user ID.
   */
  public function getPublisherId();

  /**
   * Sets the revisions entity publisher user ID.
   *
   * @param int $uid
   *   The author user id.
   *
   * @return \Drupal\config_entity_revisions\ConfigEntityRevisionsInterface
   *   The called revisions entity.
   */
  public function setPublisherId($uid);

  /**
   * Returns the revisions entity type.
   *
   * @return \Drupal\config_entity_revisions\ConfigEntityRevisionsTypeInterface
   *   The revisions entity type.
   */
  public function getType();

}
